translate.convert.po2ts

Package translate :: Package convert :: Module po2ts |
[hide private]
[frames] | no frames]

# Module po2ts

source code

convert Gettext PO localization files to Qt Linguist (.ts) files

see: http://translate.sourceforge.net/wiki/toolkit/po2ts for examples and usage instructions

Classes | [hide private]
| po2ts

Functions | [hide private]
convertpo(inputfile, outputfile, templatefile, context) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Imports: po, ts